/****************************************************************************
** Meta object code from reading C++ file 'taskcollection.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kleopatra-26.08.0/src/crypto/taskcollection.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'taskcollection.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Kleo6Crypto14TaskCollectionE_t {};
} // unnamed namespace

template <> constexpr inline auto Kleo::Crypto::TaskCollection::qt_create_metaobjectdata<qt_meta_tag_ZN4Kleo6Crypto14TaskCollectionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kleo::Crypto::TaskCollection",
        "progress",
        "",
        "processed",
        "total",
        "result",
        "std::shared_ptr<const Kleo::Crypto::Task::Result>",
        "started",
        "std::shared_ptr<Kleo::Crypto::Task>",
        "task",
        "done",
        "taskResult",
        "taskStarted"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'progress'
        QtMocHelpers::SignalData<void(int, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Signal 'result'
        QtMocHelpers::SignalData<void(const std::shared_ptr<const Kleo::Crypto::Task::Result> &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 5 },
        }}),
        // Signal 'started'
        QtMocHelpers::SignalData<void(const std::shared_ptr<Kleo::Crypto::Task> &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'done'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'taskResult'
        QtMocHelpers::SlotData<void(std::shared_ptr<const Kleo::Crypto::Task::Result>)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Slot 'taskStarted'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TaskCollection, qt_meta_tag_ZN4Kleo6Crypto14TaskCollectionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kleo::Crypto::TaskCollection::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kleo6Crypto14TaskCollectionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kleo6Crypto14TaskCollectionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Kleo6Crypto14TaskCollectionE_t>.metaTypes,
    nullptr
} };

void Kleo::Crypto::TaskCollection::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TaskCollection *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->progress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->result((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<const Kleo::Crypto::Task::Result>>>(_a[1]))); break;
        case 2: _t->started((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<Kleo::Crypto::Task>>>(_a[1]))); break;
        case 3: _t->done(); break;
        case 4: _t->d->taskResult((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<const Kleo::Crypto::Task::Result>>>(_a[1]))); break;
        case 5: _t->d->taskStarted(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TaskCollection::*)(int , int )>(_a, &TaskCollection::progress, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TaskCollection::*)(const std::shared_ptr<const Kleo::Crypto::Task::Result> & )>(_a, &TaskCollection::result, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TaskCollection::*)(const std::shared_ptr<Kleo::Crypto::Task> & )>(_a, &TaskCollection::started, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TaskCollection::*)()>(_a, &TaskCollection::done, 3))
            return;
    }
}

const QMetaObject *Kleo::Crypto::TaskCollection::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kleo::Crypto::TaskCollection::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kleo6Crypto14TaskCollectionE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kleo::Crypto::TaskCollection::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Kleo::Crypto::TaskCollection::progress(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Kleo::Crypto::TaskCollection::result(const std::shared_ptr<const Kleo::Crypto::Task::Result> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Kleo::Crypto::TaskCollection::started(const std::shared_ptr<Kleo::Crypto::Task> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Kleo::Crypto::TaskCollection::done()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
